==> dhall-json-1.7.12-121-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-Fap6YdJkAOD9eZbsqY58M5
key:                  dhall-json-1.7.12-Fap6YdJkAOD9eZbsqY58M5
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  01b0feca493b6b9260794c789f69032b
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-Fap6YdJkAOD9eZbsqY58M5
depends:
    aeson-2.1.2.1-6ANjbGmrSDg8K6hz3VmYXP
    aeson-pretty-0.8.10-6UR3e8LgzRvIwEvRPnGaD4
    aeson-yaml-1.1.0.1-K2sJgmZRmeH3wd0QWTLKyV base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.2-KV7UFpU9RFAI5KtvsaxwTf exceptions-0.10.5
    filepath-1.4.2.2 lens-family-core-2.1.3-Ij4qXDXH4U49wX5TL83dlV
    optparse-applicative-0.18.1.0-CKCQVkeW052FlPJiFlkCaf
    prettyprinter-1.7.1-H1CnA9YdkYYkwP4aBwQ7e
    scientific-0.3.8.0-eAJHzbOczMAHNfebkRy2Z text-2.0.2
    unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7
    vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-json-1.7.12-122-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-json
version:              1.7.12
visibility:           public
id:                   dhall-json-1.7.12-LNIknWO6lkxBro8eJygrHE
key:                  dhall-json-1.7.12-LNIknWO6lkxBro8eJygrHE
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and JSON or YAML
description:
    Use this package if you want to convert between Dhall expressions and JSON
    or YAML. You can use this package as a library or an executable:

    * See the "Dhall.JSON" or "Dhall.JSONToDhall" modules if you want to use
    this package as a library

    * Use the @dhall-to-json@, @dhall-to-yaml@, or @json-to-dhall@ programs from
    this package if you want an executable

    The "Dhall.JSON" and "Dhall.JSONToDhall" modules also contains instructions
    for how to use this package

category:             Compiler
abi:                  e4425b88b831c36ab72c02697a1fe8b0
exposed:              True
exposed-modules:
    Dhall.DhallToYaml.Main Dhall.JSON Dhall.JSON.Yaml Dhall.JSONToDhall

hidden-modules:       Dhall.JSON.Compat Dhall.JSON.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-json-1.7.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-json
hs-libraries:         HSdhall-json-1.7.12-LNIknWO6lkxBro8eJygrHE
depends:
    aeson-2.1.2.1-JflO2jKMgLf4qHLretO6v3
    aeson-pretty-0.8.10-4jYTVUzf20XD2mi58X3Oq8
    aeson-yaml-1.1.0.1-AWTPO2qP4Ah39ZCZBLnGOF base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.2-CvgoyZO6sZ2tw7dBuYfio exceptions-0.10.5
    filepath-1.4.2.2 lens-family-core-2.1.3-Ij4qXDXH4U49wX5TL83dlV
    optparse-applicative-0.18.1.0-LGvZkTwKuqyFBAUogcAFyK
    prettyprinter-1.7.1-Da1BCiI1NV6LfdDEPEDf77
    scientific-0.3.8.0-8fLTd8S79uT7C3Z3GpM5Vd text-2.0.2
    unordered-containers-0.2.20-Eo1ocpXri5ABLOF81VToPu
    vector-0.13.2.0-ByKMfTK8tTR39fPNQcIOcc

haddock-interfaces:   /usr/share/doc/dhall-json/html/dhall-json.haddock
haddock-html:         /usr/share/doc/dhall-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
